<!doctype html>
<html lang="<?= config('language_code') ?>">
<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1, user-scalable=no">
    <meta name="theme-color" content="#35A768">
    <meta name="google" content="notranslate">

    <meta property="og:title" content="<?= lang('page_title') . ' ' . vars('company_name') ?> | TFE Group"/>
    <meta property="og:url" content="<?= base_url() ?>">
    <meta property="og:image" content="<?= base_url('assets/img/social-card.png') ?>"/>
    <meta property="og:type" content="website">

    <?php slot('meta'); ?>

    <title><?= lang('page_title') . ' ' . vars('company_name') ?> | TFE Group</title>

    <link rel="icon" type="image/x-icon" href="<?= asset_url('assets/img/favicon.ico') ?>">
    <link rel="icon" sizes="192x192" href="<?= asset_url('assets/img/logo.png') ?>">

    <link rel="stylesheet" type="text/css" href="<?= asset_url('assets/vendor/cookieconsent/cookieconsent.min.css') ?>">
    <link rel="stylesheet" type="text/css" href="<?= asset_url('assets/vendor/flatpickr/flatpickr.min.css') ?>">
    <link rel="stylesheet" type="text/css" href="<?= asset_url('assets/vendor/flatpickr/material_green.min.css') ?>">
    <link rel="stylesheet" type="text/css" href="<?= asset_url('assets/css/themes/' . vars('theme') . '.css') ?>">
    <link rel="stylesheet" type="text/css" href="<?= asset_url('assets/css/general.css') ?>">
    <link rel="stylesheet" type="text/css" href="<?= asset_url('assets/css/layouts/booking_layout.css') ?>">

    <?php component('company_color_style', ['company_color' => vars('company_color')]); ?>

    <?php slot('styles'); ?>

    <style>
        .icon-container-wrapper {
            display: flex;
            justify-content: center;
            align-items: center;
            /* height: 72.8vh; This makes the container fill the full height of the viewport */
            flex-direction: column;
            min-height: 689px; /* This ensures the container has a minimum height */
        }
        .icon-container {
            display: flex;
            flex-wrap: wrap;
            justify-content: space-around;
            width: 100%; /* Ensure it takes the full width available */
            max-width: 600px; /* Optional: limit the max width */
        }
        .icon-button {
            display: flex;
            align-items: center;
            justify-content: center;
            flex-direction: column;
            text-align: center;
            margin: 20px;
            padding: 20px;
            border: 1px solid #ddd;
            border-radius: 8px;
            width: 150px;
            height: 150px;
            transition: background-color 0.3s;
        }
        .icon-button i {
            font-size: 56px;
            margin-bottom: 20px;
        }
        .icon-button span {
            margin-top: 10px;
        }
        .icon-button:hover {
            background-color: #429a82;
        }
        .icon-button .svg-inline--fa {
            width: 38px; /* Adjust the size as needed */
            height: 38px; /* Adjust the size as needed */
        }
    </style>
</head>

<body>
<div id="main" class="container">
    <div class="row wrapper">
        <div id="book-appointment-wizard" class="col-12 col-lg-10 col-xl-8 col-xxl-7">
            <?php component('home_header', [
                'company_name' => vars('company_name'),
                'company_logo' => vars('company_logo'),
            ]); ?>

            <div class="icon-container-wrapper">
                <div class="icon-container">
                    <a href="<?= site_url('booking') ?>" class="icon-button btn btn-light">
                        <i class="fa-solid fa-calendar-plus"></i>
                        <span>
                            <?= lang('home_appointment_button') ?>
                        </span>
                    </a>
                    <a href="<?= site_url('home_search') ?>" class="icon-button btn btn-light">
                        <i class="fa-solid fa-search"></i>
                        <span>
                            <?= lang('home_search_button') ?>
                        </span>
                    </a>
                </div>
                <div class="icon-container">   
                    <a href="<?= site_url('home_price') ?>" class="icon-button btn btn-light">
                        <i class="fa-solid fa-dollar-sign"></i>
                        <span>
                            <?= lang('home_price_button') ?>
                        </span>
                    </a>
                    <a href="<?= site_url('home_teams') ?>" class="icon-button btn btn-light">
                        <i class="fa-solid fa-address-card"></i>
                        <span>
                            <?= lang('home_teams_button') ?>
                        </span>
                    </a>
                </div>
                <div class="icon-container">   
                    <a href="<?= site_url('home_directions') ?>" class="icon-button btn btn-light">
                        <i class="fa-solid fa-book"></i>
                        <span>
                            <?= lang('home_directions_button') ?>
                        </span>
                    </a>
                    <a href="<?= site_url('home_contact') ?>" class="icon-button btn btn-light">
                        <i class="fa-solid fa-headset"></i>
                        <span>
                            <?= lang('home_contact_button') ?>
                        </span>
                    </a>
                </div>
            </div>

            <?php component('booking_footer', ['display_login_button' => vars('display_login_button')]); ?>
        </div>
    </div>
</div>

<?php if (vars('display_cookie_notice') === '1'): ?>
    <?php component('cookie_notice_modal', ['cookie_notice_content' => vars('cookie_notice_content')]); ?>
<?php endif; ?>

<?php if (vars('display_terms_and_conditions') === '1'): ?>
    <?php component('terms_and_conditions_modal', [
        'terms_and_conditions_content' => vars('terms_and_conditions_content'),
    ]); ?>
<?php endif; ?>

<?php if (vars('display_privacy_policy') === '1'): ?>
    <?php component('privacy_policy_modal', ['privacy_policy_content' => vars('privacy_policy_content')]); ?>
<?php endif; ?>

<script src="<?= asset_url('assets/vendor/jquery/jquery.min.js') ?>"></script>
<script src="<?= asset_url('assets/vendor/cookieconsent/cookieconsent.min.js') ?>"></script>
<script src="<?= asset_url('assets/vendor/@popperjs-core/popper.min.js') ?>"></script>
<script src="<?= asset_url('assets/vendor/bootstrap/bootstrap.min.js') ?>"></script>
<script src="<?= asset_url('assets/vendor/moment/moment.min.js') ?>"></script>
<script src="<?= asset_url('assets/vendor/moment-timezone/moment-timezone-with-data.min.js') ?>"></script>
<script src="<?= asset_url('assets/vendor/@fortawesome-fontawesome-free/fontawesome.min.js') ?>"></script>
<script src="<?= asset_url('assets/vendor/@fortawesome-fontawesome-free/solid.min.js') ?>"></script>
<script src="<?= asset_url('assets/vendor/tippy.js/tippy-bundle.umd.min.js') ?>"></script>
<script src="<?= asset_url('assets/vendor/flatpickr/flatpickr.min.js') ?>"></script>

<script src="<?= asset_url('assets/js/app.js') ?>"></script>
<script src="<?= asset_url('assets/js/utils/date.js') ?>"></script>
<script src="<?= asset_url('assets/js/utils/file.js') ?>"></script>
<script src="<?= asset_url('assets/js/utils/http.js') ?>"></script>
<script src="<?= asset_url('assets/js/utils/lang.js') ?>"></script>
<script src="<?= asset_url('assets/js/utils/message.js') ?>"></script>
<script src="<?= asset_url('assets/js/utils/string.js') ?>"></script>
<script src="<?= asset_url('assets/js/utils/url.js') ?>"></script>
<script src="<?= asset_url('assets/js/utils/validation.js') ?>"></script>
<script src="<?= asset_url('assets/js/layouts/booking_layout.js') ?>"></script>
<script src="<?= asset_url('assets/js/http/localization_http_client.js') ?>"></script>

<?php component('js_vars_script'); ?>
<?php component('js_lang_script'); ?>

<?php component('google_analytics_script', ['google_analytics_code' => vars('google_analytics_code')]); ?>
<?php component('matomo_analytics_script', [
    'matomo_analytics_url' => vars('matomo_analytics_url'),
    'matomo_analytics_site_id' => vars('matomo_analytics_site_id'),
]); ?>

<?php slot('scripts'); ?>

</body>
</html>