<!doctype html>
<html lang="<?= config('language_code') ?>">
<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1, user-scalable=no">
    <meta name="theme-color" content="#35A768">
    <meta name="google" content="notranslate">

    <meta property="og:title" content="<?= lang('page_title') . ' ' . vars('company_name') ?> | TFE Group"/>
    <meta property="og:url" content="<?= base_url() ?>">
    <meta property="og:image" content="<?= base_url('assets/img/social-card.png') ?>"/>
    <meta property="og:type" content="website">

    <?php slot('meta'); ?>

    <title><?= lang('page_title') . ' ' . vars('company_name') ?> | TFE Group</title>

    <link rel="icon" type="image/x-icon" href="<?= asset_url('assets/img/favicon.ico') ?>">
    <link rel="icon" sizes="192x192" href="<?= asset_url('assets/img/logo.png') ?>">

    <link rel="stylesheet" type="text/css" href="<?= asset_url('assets/vendor/cookieconsent/cookieconsent.min.css') ?>">
    <link rel="stylesheet" type="text/css" href="<?= asset_url('assets/vendor/flatpickr/flatpickr.min.css') ?>">
    <link rel="stylesheet" type="text/css" href="<?= asset_url('assets/vendor/flatpickr/material_green.min.css') ?>">
    <link rel="stylesheet" type="text/css" href="<?= asset_url('assets/css/themes/' . vars('theme') . '.css') ?>">
    <link rel="stylesheet" type="text/css" href="<?= asset_url('assets/css/general.css') ?>">
    <link rel="stylesheet" type="text/css" href="<?= asset_url('assets/css/layouts/booking_layout.css') ?>">

    <?php component('company_color_style', ['company_color' => vars('company_color')]); ?>

    <?php slot('styles'); ?>

    <style>
        .doctor-profile {
            display: flex;
            flex-direction: column;
            align-items: center;
            margin: 20px 10px 20px 10px;
            text-align: center;
        }
        .container {
            width: 100%;
            margin: 0 auto;
            padding: 20px;
        }
        .header {
            text-align: center;
            margin-bottom: 40px;
        }
        .header h1 {
            color: #20a27f;
            font-size: 36px;
        }
        .doctor-grid {
            display: flex;
            flex-wrap: nowrap;
            justify-content: space-around;
            gap: 20px;
        }
        .doctor-card {
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
            overflow: hidden;
            width: 230px;
            text-align: center;
            transition: transform 0.3s;
        }
        .doctor-card:hover {
            transform: translateY(-10px);
        }
        .doctor-photo img {
            width: 100%;
            height: auto;
            border-bottom: 4px solid #20a27f;
        }
        .doctor-info {
            padding: 20px;
        }
        .doctor-name {
            font-size: 24px;
            color: #333;
            margin-bottom: 10px;
        }
        .doctor-specialty {
            font-size: 18px;
            color: #20a27f;
            margin-bottom: 10px;
        }
        .doctor-description {
            font-size: 16px;
            color: #666;
            margin-bottom: 10px;
        }
        .doctor-schedule {
            font-size: 16px;
            color: #333;
        }

        /* 媒体查询 */
        @media (max-width: 768px) {
            .doctor-grid {
                flex-direction: column;
                align-items: center;
            }
            .doctor-card {
            width: 350px;
        }
        }
    </style>
</head>

<body>
<div id="main" class="container">
    <div class="row wrapper">
        <div id="book-appointment-wizard" class="col-12 col-lg-10 col-xl-8 col-xxl-7">
            <?php component('home_header', [
                'company_name' => vars('company_name'),
                'company_logo' => vars('company_logo'),
            ]); ?>
            <div class="doctor-profile">

                <div class="doctor-grid">
                    <div class="doctor-card">
                        <div class="doctor-photo">
                            <img src="<?= asset_url('assets/img/male.jpeg') ?>" alt="医生照片">
                        </div>
                        <div class="doctor-info">
                            <div class="doctor-name">马医师</div>
                            <div class="doctor-specialty">中藥 | 針灸 | 跌打</div>
                            <div class="doctor-description">
                                擅长以针刺、火针、穴位埋线、穴位注射、耳穴等中医特色疗法治疗颈肩腰腿痛，坐骨神经痛，失眠，便秘，鼻炎，咽炎，痛经，月经不调等症。
                            </div>
                            <div class="doctor-schedule">
                                坐诊时间: 每周二、三、五、六 13:00 - 20:00
                            </div>
                        </div>
                    </div>

                    <!-- 其他医生卡片可以复制上面的结构并替换内容 -->
                    <div class="doctor-card">
                        <div class="doctor-photo">
                            <img src="<?= asset_url('assets/img/fimale.jpeg') ?>" alt="医生照片">
                        </div>
                        <div class="doctor-info">
                            <div class="doctor-name">李医师</div>
                            <div class="doctor-specialty">內科 | 婦科</div>
                            <div class="doctor-description">
                                擅于治疗中医内妇科常见病，针灸疗法治疗损美性疾病，神经系统疾病及痛症。
                            </div>
                            <div class="doctor-schedule">
                                坐诊时间: 每周日 12:00 - 17:00
                            </div>
                        </div>
                    </div>


                    <!-- 其他医生卡片可以复制上面的结构并替换内容 -->
                    <div class="doctor-card">
                        <div class="doctor-photo">
                            <img src="<?= asset_url('assets/img/fimale.jpeg') ?>" alt="医生照片">
                        </div>
                        <div class="doctor-info">
                            <div class="doctor-name">张医师</div>
                            <div class="doctor-specialty">兒科 | 中藥 | 針灸</div>
                            <div class="doctor-description">
                                擅长运用中医传统技术治疗颈肩腰腿疾病、临床内科、妇科及儿科常见病、小儿推拿等。
                            </div>
                            <div class="doctor-schedule">
                                坐诊时间: 每周四 13:00 - 20:00
                            </div>
                        </div>
                    </div>
                    
                    <!-- 继续添加其他医生卡片 -->
                </div>

            </div>

            <?php component('booking_footer', ['display_login_button' => vars('display_login_button')]); ?>
        </div>
    </div>
</div>

<?php if (vars('display_cookie_notice') === '1'): ?>
    <?php component('cookie_notice_modal', ['cookie_notice_content' => vars('cookie_notice_content')]); ?>
<?php endif; ?>

<?php if (vars('display_terms_and_conditions') === '1'): ?>
    <?php component('terms_and_conditions_modal', [
        'terms_and_conditions_content' => vars('terms_and_conditions_content'),
    ]); ?>
<?php endif; ?>

<?php if (vars('display_privacy_policy') === '1'): ?>
    <?php component('privacy_policy_modal', ['privacy_policy_content' => vars('privacy_policy_content')]); ?>
<?php endif; ?>

<script src="<?= asset_url('assets/vendor/jquery/jquery.min.js') ?>"></script>
<script src="<?= asset_url('assets/vendor/cookieconsent/cookieconsent.min.js') ?>"></script>
<script src="<?= asset_url('assets/vendor/@popperjs-core/popper.min.js') ?>"></script>
<script src="<?= asset_url('assets/vendor/bootstrap/bootstrap.min.js') ?>"></script>
<script src="<?= asset_url('assets/vendor/moment/moment.min.js') ?>"></script>
<script src="<?= asset_url('assets/vendor/moment-timezone/moment-timezone-with-data.min.js') ?>"></script>
<script src="<?= asset_url('assets/vendor/@fortawesome-fontawesome-free/fontawesome.min.js') ?>"></script>
<script src="<?= asset_url('assets/vendor/@fortawesome-fontawesome-free/solid.min.js') ?>"></script>
<script src="<?= asset_url('assets/vendor/tippy.js/tippy-bundle.umd.min.js') ?>"></script>
<script src="<?= asset_url('assets/vendor/flatpickr/flatpickr.min.js') ?>"></script>

<script src="<?= asset_url('assets/js/app.js') ?>"></script>
<script src="<?= asset_url('assets/js/utils/date.js') ?>"></script>
<script src="<?= asset_url('assets/js/utils/file.js') ?>"></script>
<script src="<?= asset_url('assets/js/utils/http.js') ?>"></script>
<script src="<?= asset_url('assets/js/utils/lang.js') ?>"></script>
<script src="<?= asset_url('assets/js/utils/message.js') ?>"></script>
<script src="<?= asset_url('assets/js/utils/string.js') ?>"></script>
<script src="<?= asset_url('assets/js/utils/url.js') ?>"></script>
<script src="<?= asset_url('assets/js/utils/validation.js') ?>"></script>
<script src="<?= asset_url('assets/js/layouts/booking_layout.js') ?>"></script>
<script src="<?= asset_url('assets/js/http/localization_http_client.js') ?>"></script>

<?php component('js_vars_script'); ?>
<?php component('js_lang_script'); ?>

<?php component('google_analytics_script', ['google_analytics_code' => vars('google_analytics_code')]); ?>
<?php component('matomo_analytics_script', [
    'matomo_analytics_url' => vars('matomo_analytics_url'),
    'matomo_analytics_site_id' => vars('matomo_analytics_site_id'),
]); ?>

<?php slot('scripts'); ?>

</body>
</html>